@@ -1,6 +1,16 @@
 /* Copyright Contributors to the Open Cluster Management project */
 
-import { Provider } from '@stolostron/ui-components'
+import {
+    DiscoveryConfig,
+    DiscoveryConfigApiVersion,
+    DiscoveryConfigKind,
+    ProviderConnection,
+    ProviderConnectionApiVersion,
+    ProviderConnectionKind,
+    ResourceAttributes,
+    Secret,
+} from '../../resources'
+import { Provider } from '@open-cluster-management/ui-components'
 import { render, waitFor } from '@testing-library/react'
 import { Scope } from 'nock/types'
 import { MemoryRouter, Route } from 'react-router-dom'
@@ -18,13 +28,6 @@ import {
     waitForText,
 } from '../../lib/test-util'
 import { NavigationPath } from '../../NavigationPath'
-import { DiscoveryConfig, DiscoveryConfigApiVersion, DiscoveryConfigKind } from '../../resources/discovery-config'
-import {
-    ProviderConnection,
-    ProviderConnectionApiVersion,
-    ProviderConnectionKind,
-} from '../../resources/provider-connection'
-import { ResourceAttributes } from '../../resources/self-subject-access-review'
 import CredentialsPage from './Credentials'
 
 const mockProviderConnection1: ProviderConnection = {
@@ -112,7 +115,7 @@ function TestProviderConnectionsPage(props: {
     return (
         <RecoilRoot
             initializeState={(snapshot) => {
-                snapshot.set(secretsState, props.providerConnections)
+                snapshot.set(secretsState, props.providerConnections as Secret[])
                 snapshot.set(discoveryConfigState, props.discoveryConfigs || [])
             }}
         >
