@@ -1,26 +1,30 @@
 /* Copyright Contributors to the Open Cluster Management project */
 
-import { useState, useContext } from 'react'
+import { useState, useContext, useEffect } from 'react'
 import { useRecoilState } from 'recoil'
-import { AcmPage, AcmPageContent, AcmPageHeader, AcmErrorBoundary, AcmToastContext } from '@stolostron/ui-components'
+import {
+    AcmPage,
+    AcmPageContent,
+    AcmPageHeader,
+    AcmErrorBoundary,
+    AcmToastContext,
+} from '@open-cluster-management/ui-components'
 import { PageSection } from '@patternfly/react-core'
 import { createCluster } from '../../../../../lib/create-cluster'
 import { useTranslation } from 'react-i18next'
 import { useHistory, useLocation } from 'react-router-dom'
 import { NavigationPath } from '../../../../../NavigationPath'
-import fs from 'fs'
-import path from 'path'
 import Handlebars from 'handlebars'
 import { DOC_LINKS } from '../../../../../lib/doc-util'
-import { namespacesState } from '../../../../../atoms'
+import { namespacesState, settingsState } from '../../../../../atoms'
 import { useCanJoinClusterSets, useMustJoinClusterSet } from '../../ClusterSets/components/useCanJoinClusterSets'
 import '../../ManagedClusters/CreateCluster/style.css'
 
 // template/data
-import { controlData } from './controlData/ControlData'
+import { getControlData } from './controlData/ControlData'
 import { setAvailableConnections } from '../../ManagedClusters/CreateCluster/controlData/ControlDataHelpers'
 import hiveTemplate from './templates/hive-template.hbs'
-import { secretsState, settingsState } from '../../../../../atoms'
+import { secretsState } from '../../../../../atoms'
 
 import TemplateEditor from 'temptifly'
 import 'temptifly/dist/styles.css'
@@ -28,29 +32,7 @@ import 'temptifly/dist/styles.css'
 // include monaco editor
 import MonacoEditor from 'react-monaco-editor'
 import 'monaco-editor/esm/vs/editor/editor.all.js'
-import 'monaco-editor/esm/vs/editor/standalone/browser/quickOpen/quickCommand.js'
 import 'monaco-editor/esm/vs/basic-languages/yaml/yaml.contribution.js'
-import { global_BackgroundColor_dark_100 as editorBackground } from '@patternfly/react-tokens'
-declare const window: any
-if (window.monaco) {
-    window.monaco.editor.defineTheme('console', {
-        base: 'vs-dark',
-        inherit: true,
-        rules: [
-            // avoid pf tokens for `rules` since tokens are opaque strings that might not be hex values
-            { token: 'number', foreground: 'ace12e' },
-            { token: 'type', foreground: '73bcf7' },
-            { token: 'string', foreground: 'f0ab00' },
-            { token: 'keyword', foreground: 'cbc0ff' },
-        ],
-        colors: {
-            'editor.background': editorBackground?.value,
-            'editorGutter.background': '#292e34', // no pf token defined
-            'editorLineNumber.activeForeground': '#fff',
-            'editorLineNumber.foreground': '#f0f0f0',
-        },
-    })
-}
 interface CreationStatus {
     status: string
     messages: any[] | null
@@ -125,6 +107,14 @@ export function CreateClusterPool() {
     const toastContext = useContext(AcmToastContext)
     const [settings] = useRecoilState(settingsState)
 
+    // if a connection is added outside of wizard, add it to connection selection
+    const [connectionControl, setConnectionControl] = useState()
+    useEffect(() => {
+        if (connectionControl) {
+            setAvailableConnections(connectionControl, secrets)
+        }
+    }, [connectionControl, secrets])
+
     // create button
     const [creationStatus, setCreationStatus] = useState<CreationStatus>()
     const createResource = async (resourceJSON: { createResources: any[] }) => {
@@ -162,11 +152,8 @@ export function CreateClusterPool() {
         return t(key, arg)
     }
 
-    let template = hiveTemplate
-    // react-scripts HATE jest transforms so we got to load the templates ourselves
-    if (typeof hiveTemplate === 'string') {
-        template = Handlebars.compile(fs.readFileSync(path.resolve(__dirname, './templates/hive-template.hbs'), 'utf8'))
-    }
+    //compile template
+    const template = Handlebars.compile(hiveTemplate)
 
     // if openned from bma page, pass selected bma's to editor
     const urlParams = new URLSearchParams(location.search.substring(1))
@@ -183,6 +170,9 @@ export function CreateClusterPool() {
     const mustJoinClusterSet = useMustJoinClusterSet()
     function onControlInitialize(control: any) {
         switch (control.id) {
+            case 'connection':
+                setConnectionControl(control)
+                break
             case 'clusterSet':
                 if (control.available) {
                     control.available = canJoinClusterSets?.map((mcs) => mcs.metadata.name) ?? []
@@ -220,7 +210,10 @@ export function CreateClusterPool() {
             type={'ClusterPool'}
             title={'ClusterPool YAML'}
             monacoEditor={<MonacoEditor />}
-            controlData={controlData}
+            controlData={getControlData(
+                settings.awsPrivateWizardStep === 'enabled',
+                settings.singleNodeOpenshift === 'enabled'
+            )}
             template={template}
             portals={Portals}
             fetchControl={fetchControl}
