@@ -1,6 +1,20 @@
 /* Copyright Contributors to the Open Cluster Management project */
 
 import { makeStyles } from '@material-ui/styles'
+import {
+    ClusterRoleBinding,
+    ClusterRoleBindingKind,
+    ClusterRoleKind,
+    createResource,
+    deleteResource,
+    Group,
+    listClusterRoleBindings,
+    listGroups,
+    listUsers,
+    RbacApiVersion,
+    ResourceErrorCode,
+    User,
+} from '../../../../../../resources'
 import {
     AcmAlertContext,
     AcmAlertGroup,
@@ -15,7 +29,7 @@ import {
     AcmTable,
     compareStrings,
     IAcmTableColumn,
-} from '@stolostron/ui-components'
+} from '@open-cluster-management/ui-components'
 import {
     ActionGroup,
     ButtonVariant,
@@ -31,19 +45,7 @@ import { useCallback, useContext, useMemo, useState } from 'react'
 import { Trans, useTranslation } from 'react-i18next'
 import { BulkActionModel, errorIsNot, IBulkActionModelProps } from '../../../../../../components/BulkActionModel'
 import { ErrorPage, getErrorInfo } from '../../../../../../components/ErrorPage'
-import { createResource, deleteResource, ResourceErrorCode } from '../../../../../../lib/resource-request'
 import { useQuery } from '../../../../../../lib/useQuery'
-import {
-    ClusterRoleBinding,
-    ClusterRoleBindingKind,
-    ClusterRoleKind,
-    Group,
-    listClusterRoleBindings,
-    listGroups,
-    listUsers,
-    RbacApiVersion,
-    User,
-} from '../../../../../../resources/rbac'
 import { ClusterSetContext } from '../ClusterSetDetails'
 
 export function ClusterSetAccessManagement() {
@@ -163,8 +165,15 @@ export function ClusterSetAccessManagement() {
                     items={clusterRoleBindings}
                     keyFn={keyFn}
                     columns={columns}
-                    tableActions={[{ id: 'addUserGroup', title: t('access.add'), click: () => setAddModalOpen(true) }]}
-                    bulkActions={[
+                    tableActionButtons={[
+                        {
+                            id: 'addUserGroup',
+                            title: t('access.add'),
+                            click: () => setAddModalOpen(true),
+                            variant: ButtonVariant.primary,
+                        },
+                    ]}
+                    tableActions={[
                         {
                             id: 'removeAuthorization',
                             title: t('access.remove'),
@@ -188,6 +197,7 @@ export function ClusterSetAccessManagement() {
                                     isValidError: errorIsNot([ResourceErrorCode.NotFound]),
                                 })
                             },
+                            variant: 'bulk-action',
                         },
                     ]}
                     rowActions={[
@@ -309,11 +319,17 @@ function AddUsersModal(props: {
                                     value={userGroup}
                                     onChange={(userGroup) => setUserGroup(userGroup)}
                                 >
-                                    {(type === 'User' ? filteredUsers : filteredGroups).map((item: User | Group) => (
-                                        <SelectOption key={item.metadata.uid} value={item.metadata.name}>
-                                            {item.metadata.name}
-                                        </SelectOption>
-                                    ))}
+                                    {type === 'User'
+                                        ? filteredUsers.map((item: User) => (
+                                              <SelectOption key={item.metadata.uid} value={item.metadata.name}>
+                                                  {item.metadata.name}
+                                              </SelectOption>
+                                          ))
+                                        : filteredGroups.map((item: Group) => (
+                                              <SelectOption key={item.metadata.uid} value={item.metadata.name}>
+                                                  {item.metadata.name}
+                                              </SelectOption>
+                                          ))}
                                 </AcmSelect>
                                 <ToggleGroup>
                                     <ToggleGroupItem
