@@ -1,36 +1,42 @@
 /* Copyright Contributors to the Open Cluster Management project */
 
-import { useContext, useState } from 'react'
-import { Link, useHistory } from 'react-router-dom'
-import { useTranslation, Trans } from 'react-i18next'
-import { PageSection, Stack, StackItem, Flex, FlexItem, TextContent, Text, TextVariants } from '@patternfly/react-core'
-import { fitContent } from '@patternfly/react-table'
+import { ManagedClusterAddOn, ManagedClusterSetDefinition, ResourceErrorCode } from '../../../../../../resources'
 import {
-    AcmPageContent,
-    AcmEmptyState,
-    AcmTable,
-    AcmInlineStatus,
-    StatusType,
-    AcmExpandableCard,
     AcmButton,
+    AcmEmptyState,
+    AcmExpandableCard,
     AcmInlineProvider,
-} from '@stolostron/ui-components'
-import { useRecoilState } from 'recoil'
+    AcmInlineStatus,
+    AcmPageContent,
+    AcmTable,
+    StatusType,
+} from '@open-cluster-management/ui-components'
+import {
+    ButtonVariant,
+    Flex,
+    FlexItem,
+    PageSection,
+    Stack,
+    StackItem,
+    Text,
+    TextContent,
+    TextVariants,
+} from '@patternfly/react-core'
 import { ExternalLinkAltIcon } from '@patternfly/react-icons'
-import { DOC_LINKS } from '../../../../../../lib/doc-util'
-import { ClusterSetContext } from '../ClusterSetDetails'
-import { RbacButton } from '../../../../../../components/Rbac'
-import { rbacCreate, rbacPatch } from '../../../../../../lib/rbac-util'
-import { ManagedClusterAddOn } from '../../../../../../resources/managed-cluster-add-on'
-import { NavigationPath } from '../../../../../../NavigationPath'
+import { fitContent } from '@patternfly/react-table'
+import { useContext, useState } from 'react'
+import { Trans, useTranslation } from 'react-i18next'
+import { Link, useHistory } from 'react-router-dom'
+import { useRecoilState } from 'recoil'
 import { submarinerConfigsState } from '../../../../../../atoms'
-import { ManagedClusterSetDefinition } from '../../../../../../resources/managed-cluster-set'
 import { BulkActionModel, errorIsNot, IBulkActionModelProps } from '../../../../../../components/BulkActionModel'
+import { RbacButton, RbacDropdown } from '../../../../../../components/Rbac'
 import { deleteSubmarinerAddon } from '../../../../../../lib/delete-submariner'
-import { ResourceErrorCode } from '../../../../../../lib/resource-request'
-import { rbacDelete } from '../../../../../../lib/rbac-util'
-import { RbacDropdown } from '../../../../../../components/Rbac'
+import { DOC_LINKS } from '../../../../../../lib/doc-util'
+import { rbacCreate, rbacDelete, rbacPatch } from '../../../../../../lib/rbac-util'
+import { NavigationPath } from '../../../../../../NavigationPath'
 import { EditSubmarinerConfigModal, EditSubmarinerConfigModalProps } from '../../components/EditSubmarinerConfigModal'
+import { ClusterSetContext } from '../ClusterSetDetails'
 
 type SubmarinerGatewayNodesLabeledType = 'SubmarinerGatewayNodesLabeled'
 const SubmarinerGatewayNodesLabeled: SubmarinerGatewayNodesLabeledType = 'SubmarinerGatewayNodesLabeled'
@@ -297,7 +303,7 @@ export function ClusterSetSubmarinerPageContent() {
                             ]}
                             keyFn={keyFn}
                             key="submarinerTable"
-                            bulkActions={[
+                            tableActions={[
                                 {
                                     id: 'uninstall-submariner',
                                     title: t('bulk.title.uninstallSubmariner.action'),
@@ -323,10 +329,11 @@ export function ClusterSetSubmarinerPageContent() {
                                             isValidError: errorIsNot([ResourceErrorCode.NotFound]),
                                         })
                                     },
+                                    variant: 'bulk-action',
                                 },
                             ]}
                             rowActions={[]}
-                            tableActions={[
+                            tableActionButtons={[
                                 {
                                     id: 'install-submariner',
                                     title: t('managed.clusterSets.submariner.addons.install'),
@@ -337,6 +344,7 @@ export function ClusterSetSubmarinerPageContent() {
                                                 clusterSet?.metadata.name!
                                             )
                                         ),
+                                    variant: ButtonVariant.primary,
                                 },
                             ]}
                             emptyState={
