@@ -1,6 +1,12 @@
 /* Copyright Contributors to the Open Cluster Management project */
 
-import { AcmPage, AcmPageHeader, AcmRoute, AcmSecondaryNav, AcmSecondaryNavItem } from '@stolostron/ui-components'
+import {
+    AcmPage,
+    AcmPageHeader,
+    AcmRoute,
+    AcmSecondaryNav,
+    AcmSecondaryNavItem,
+} from '@open-cluster-management/ui-components'
 import { createContext, ElementType, Fragment, lazy, ReactNode, Suspense, useContext, useEffect, useState } from 'react'
 import { useTranslation } from 'react-i18next'
 import { Link, Redirect, Route, Switch, useLocation } from 'react-router-dom'
@@ -40,7 +46,7 @@ export const usePageContext = (showActions: boolean, Component: ElementType) =>
 export default function ClusterManagementPage() {
     const [actions, setActions] = useState<undefined | ReactNode>(undefined)
     const location = useLocation()
-    const { t } = useTranslation(['cluster', 'bma'])
+    const { t } = useTranslation(['cluster', 'bma', 'common'])
 
     const [, setRoute] = useRecoilState(acmRouteState)
     useEffect(() => setRoute(AcmRoute.Clusters), [setRoute])
