@@ -108,8 +108,8 @@ export function AddDiscoveryConfigData() {
     useEffect(() => {
         const CRHCredentials: Secret[] = []
         secrets.forEach((credential) => {
-            const labels = credential.metadata.labels!['cluster.open-cluster-management.io/type']
-            if (labels === Provider.redhatcloud) {
+            const provider = credential.metadata.labels?.['cluster.open-cluster-management.io/type']
+            if (provider === Provider.redhatcloud) {
                 CRHCredentials.push(credential)
             }
         })
