@@ -1,6 +1,13 @@
 /* Copyright Contributors to the Open Cluster Management project */
 
-import { AcmEmptyState, AcmPageContent, AcmTable, compareStrings, IAcmTableColumn } from '@stolostron/ui-components'
+import { ClusterStatus, deleteResource, MachinePool } from '../../../../../../resources'
+import {
+    AcmEmptyState,
+    AcmPageContent,
+    AcmTable,
+    compareStrings,
+    IAcmTableColumn,
+} from '@open-cluster-management/ui-components'
 import { PageSection } from '@patternfly/react-core'
 import { fitContent } from '@patternfly/react-table'
 import { useContext, useState } from 'react'
@@ -9,15 +16,12 @@ import { useRecoilState } from 'recoil'
 import { machinePoolsState } from '../../../../../../atoms'
 import { BulkActionModel, IBulkActionModelProps } from '../../../../../../components/BulkActionModel'
 import { RbacDropdown } from '../../../../../../components/Rbac'
-import { ClusterStatus } from '../../../../../../lib/get-cluster'
+import { TechPreviewAlert } from '../../../../../../components/TechPreviewAlert'
+import { DOC_LINKS } from '../../../../../../lib/doc-util'
 import { rbacDelete, rbacPatch } from '../../../../../../lib/rbac-util'
-import { deleteResource } from '../../../../../../lib/resource-request'
-import { MachinePool } from '../../../../../../resources/machine-pool'
 import { ScaleClusterAlert } from '../../components/ScaleClusterAlert'
 import { ClusterContext } from '../ClusterDetails'
 import { ScaleMachinePoolModal, ScaleMachinePoolModalProps } from './components/ScaleMachinePoolModal'
-import { TechPreviewAlert } from '../../../../../../components/TechPreviewAlert'
-import { DOC_LINKS } from '../../../../../../lib/doc-util'
 
 export function MachinePoolsPageContent() {
     return (
@@ -218,7 +222,6 @@ export function MachinePoolsTable() {
                 columns={columns}
                 keyFn={keyFn}
                 tableActions={[]}
-                bulkActions={[]}
                 rowActions={[]}
                 emptyState={
                     <AcmEmptyState
