@@ -1,63 +1,51 @@
 /* Copyright Contributors to the Open Cluster Management project */
-
-import { AcmErrorBoundary, AcmPageContent, AcmPage, AcmPageHeader } from '@stolostron/ui-components'
+import { AcmErrorBoundary, AcmPageContent, AcmPage, AcmPageHeader } from '@open-cluster-management/ui-components'
 import { PageSection } from '@patternfly/react-core'
-import { global_BackgroundColor_dark_100 as editorBackground } from '@patternfly/react-tokens'
-import fs from 'fs'
 import Handlebars from 'handlebars'
 import { get, keyBy } from 'lodash'
-import path from 'path'
-import { useState } from 'react'
+import { useState, useRef, useEffect } from 'react'
 import { useTranslation } from 'react-i18next'
 import { useRecoilState } from 'recoil'
 // include monaco editor
 import MonacoEditor from 'react-monaco-editor'
 import 'monaco-editor/esm/vs/editor/editor.all.js'
-import 'monaco-editor/esm/vs/editor/standalone/browser/quickOpen/quickCommand.js'
 import 'monaco-editor/esm/vs/basic-languages/yaml/yaml.contribution.js'
 import { useHistory, useLocation } from 'react-router-dom'
 import TemplateEditor from 'temptifly'
 import 'temptifly/dist/styles.css'
+//import TemplateEditor from 'C:/Users/jswanke/git2/temptifly/src' //'temptifly'
 import { DOC_LINKS } from '../../../../../lib/doc-util'
 import { NavigationPath } from '../../../../../NavigationPath'
 import { useCanJoinClusterSets, useMustJoinClusterSet } from '../../ClusterSets/components/useCanJoinClusterSets'
 // template/data
-import { controlData } from './controlData/ControlData'
+import { getControlData } from './controlData/ControlData'
 import { setAvailableConnections, setAvailableTemplates } from './controlData/ControlDataHelpers'
 import './style.css'
 import hiveTemplate from './templates/hive-template.hbs'
-import { secretsState, managedClustersState, clusterCuratorsState, settingsState } from '../../../../../atoms'
+import endpointTemplate from './templates/endpoints.hbs'
+import {
+    secretsState,
+    managedClustersState,
+    clusterCuratorsState,
+    agentClusterInstallsState,
+    infraEnvironmentsState,
+    settingsState,
+} from '../../../../../atoms'
 import { makeStyles } from '@material-ui/styles'
 import {
     ClusterCurator,
     filterForTemplatedCurators,
     createClusterCurator,
-} from '../../../../../resources/cluster-curator'
+    patchResource,
+} from '../../../../../resources'
 import { createCluster } from '../../../../../lib/create-cluster'
-import { ProviderConnection, unpackProviderConnection } from '../../../../../resources/provider-connection'
-import { Secret } from '../../../../../resources/secret'
-import { createResource as createResourceTool } from '../../../../../lib/resource-request'
+import { ProviderConnection, unpackProviderConnection } from '../../../../../resources'
+import { Secret } from '../../../../../resources'
+import { createResource as createResourceTool } from '../../../../../resources'
+import { getNetworkingPatches } from './components/assisted-installer/utils'
+import { CIM } from 'openshift-assisted-ui-lib'
+import { WarningContext, WarningContextType, Warning } from './Warning'
 
-declare const window: any
-if (window.monaco) {
-    window.monaco.editor.defineTheme('console', {
-        base: 'vs-dark',
-        inherit: true,
-        rules: [
-            // avoid pf tokens for `rules` since tokens are opaque strings that might not be hex values
-            { token: 'number', foreground: 'ace12e' },
-            { token: 'type', foreground: '73bcf7' },
-            { token: 'string', foreground: 'f0ab00' },
-            { token: 'keyword', foreground: 'cbc0ff' },
-        ],
-        colors: {
-            'editor.background': editorBackground.value,
-            'editorGutter.background': '#292e34', // no pf token defined
-            'editorLineNumber.activeForeground': '#fff',
-            'editorLineNumber.foreground': '#f0f0f0',
-        },
-    })
-}
 interface CreationStatus {
     status: string
     messages: any[] | null
@@ -82,6 +70,15 @@ export default function CreateClusterPage() {
     const history = useHistory()
     const location = useLocation()
     const [secrets] = useRecoilState(secretsState)
+    const templateEditorRef = useRef<null>()
+
+    // if a connection is added outside of wizard, add it to connection selection
+    const [connectionControl, setConnectionControl] = useState()
+    useEffect(() => {
+        if (connectionControl) {
+            setAvailableConnections(connectionControl, secrets)
+        }
+    }, [connectionControl, secrets])
 
     const providerConnections = secrets.map(unpackProviderConnection)
     const ansibleCredentials = providerConnections.filter(
@@ -90,11 +87,19 @@ export default function CreateClusterPage() {
     )
 
     const [settings] = useRecoilState(settingsState)
+
     const [managedClusters] = useRecoilState(managedClustersState)
     const [clusterCurators] = useRecoilState(clusterCuratorsState)
     const curatorTemplates = filterForTemplatedCurators(clusterCurators)
     const [selectedTemplate, setSelectedTemplate] = useState('')
     const [selectedConnection, setSelectedConnection] = useState<ProviderConnection>()
+    const [agentClusterInstalls] = useRecoilState(agentClusterInstallsState)
+    const [infraEnvs] = useRecoilState(infraEnvironmentsState)
+    const [warning, setWarning] = useState<WarningContextType>()
+
+    // Is there a way how to get this without fetching all InfraEnvs?
+    const isInfraEnvAvailable = !!infraEnvs?.length
+
     const classes = useStyles()
     // create portals for buttons in header
     const switches = (
@@ -112,7 +117,12 @@ export default function CreateClusterPage() {
 
     // create button
     const [creationStatus, setCreationStatus] = useState<CreationStatus>()
-    const createResource = async (resourceJSON: { createResources: any[] }, control: any) => {
+    const createResource = async (
+        resourceJSON: { createResources: any[] },
+        noRedirect: boolean,
+        inProgressMsg?: string,
+        completedMsg?: string
+    ) => {
         if (resourceJSON) {
             const { createResources } = resourceJSON
             const map = keyBy(createResources, 'kind')
@@ -120,12 +130,14 @@ export default function CreateClusterPage() {
 
             // return error if cluster name is already used
             const matchedManagedCluster = managedClusters.find((mc) => mc.metadata.name === clusterName)
+            const matchedAgentClusterInstall = agentClusterInstalls.find((mc) => mc.metadata.name === clusterName)
 
-            if (matchedManagedCluster) {
-                return setCreationStatus({
+            if (matchedManagedCluster || matchedAgentClusterInstall) {
+                setCreationStatus({
                     status: 'ERROR',
                     messages: [{ message: `The cluster name is already used by another cluster.` }],
                 })
+                return 'ERROR'
             } else {
                 // check if Template is selected
                 if (selectedTemplate !== '') {
@@ -149,13 +161,19 @@ export default function CreateClusterPage() {
                     }
                 })
 
-                setCreationStatus({ status: 'IN_PROGRESS', messages: [] })
+                const progressMessage = inProgressMsg ? [inProgressMsg] : []
+                setCreationStatus({ status: 'IN_PROGRESS', messages: progressMessage })
 
                 // creates managedCluster, deployment, secrets etc...
                 const { status, messages } = await createCluster(createResources)
-                setCreationStatus({ status, messages })
 
-                if (status !== 'ERROR' && selectedTemplate !== '') {
+                if (status === 'ERROR') {
+                    setCreationStatus({ status, messages })
+                } else if (status !== 'ERROR' && selectedTemplate !== '') {
+                    setCreationStatus({
+                        status: 'IN_PROGRESS',
+                        messages: ['Running automation...'],
+                    })
                     // get template, modifty it and create curator cluster namespace
                     const currentTemplate = curatorTemplates.find(
                         (template) => template.metadata.name === selectedTemplate
@@ -199,10 +217,16 @@ export default function CreateClusterPage() {
 
                 // redirect to created cluster
                 if (status === 'DONE') {
-                    setTimeout(() => {
-                        history.push(NavigationPath.clusterDetails.replace(':id', clusterName as string))
-                    }, 2000)
+                    const finishMessage = completedMsg ? [completedMsg] : []
+                    setCreationStatus({ status, messages: finishMessage })
+                    if (!noRedirect) {
+                        setTimeout(() => {
+                            history.push(NavigationPath.clusterDetails.replace(':id', clusterName as string))
+                        }, 2000)
+                    }
                 }
+
+                return status
             }
         }
     }
@@ -216,20 +240,14 @@ export default function CreateClusterPage() {
     const pauseCreate = () => {}
 
     // setup translation
-    const { t } = useTranslation(['create'])
-    const i18n = (key: any, arg: any) => {
+    const { t } = useTranslation(['create', 'cim'])
+    const i18n = (key: string, arg: any) => {
         return t(key, arg)
     }
 
-    let template = hiveTemplate
-    // react-scripts HATE jest transforms so we got to load the templates ourselves
-    if (typeof hiveTemplate === 'string') {
-        template = Handlebars.compile(fs.readFileSync(path.resolve(__dirname, './templates/hive-template.hbs'), 'utf8'))
-        Handlebars.registerPartial(
-            'endpoints',
-            Handlebars.compile(fs.readFileSync(path.resolve(__dirname, './templates/endpoints.hbs'), 'utf8'))
-        )
-    }
+    //compile templates
+    const template = Handlebars.compile(hiveTemplate)
+    Handlebars.registerPartial('endpoints', Handlebars.compile(endpointTemplate))
 
     // if openned from bma page, pass selected bma's to editor
     const urlParams = new URLSearchParams(location.search.substring(1))
@@ -246,6 +264,9 @@ export default function CreateClusterPage() {
     const mustJoinClusterSet = useMustJoinClusterSet()
     function onControlInitialize(control: any) {
         switch (control.id) {
+            case 'connection':
+                setConnectionControl(control)
+                break
             case 'clusterSet':
                 if (control.available) {
                     control.available = canJoinClusterSets?.map((mcs) => mcs.metadata.name) ?? []
@@ -270,6 +291,63 @@ export default function CreateClusterPage() {
                 if (settings.singleNodeOpenshift === 'enabled') {
                     control.active = true
                 }
+                break
+            case 'reviewSave':
+                control.mutation = (controlData: any[]) => {
+                    return new Promise((resolve) => {
+                        if (templateEditorRef.current) {
+                            const resourceJSON = (templateEditorRef.current as any)?.getResourceJSON()
+                            if (resourceJSON) {
+                                const networkForm = controlData.find((r: any) => r.id === 'aiNetwork')
+                                if (networkForm) {
+                                    networkForm.resourceJSON = resourceJSON
+                                }
+                                const hostsForm = controlData.find((r: any) => r.id === 'aiHosts')
+                                if (hostsForm) {
+                                    hostsForm.resourceJSON = resourceJSON
+                                }
+                                createResource(resourceJSON, true, 'Saving draft...', 'Draft saved').then((status) => {
+                                    if (status === 'ERROR') {
+                                        resolve(status)
+                                    } else {
+                                        setTimeout(() => {
+                                            resolve(status)
+                                            setCreationStatus(undefined)
+                                        }, 250)
+                                    }
+                                })
+                                return
+                            }
+                        }
+                        resolve('ERROR')
+                    })
+                }
+                break
+            case 'reviewFinish':
+                control.mutation = async (controlData: any[]) => {
+                    return new Promise((resolve) => {
+                        const networkForm = controlData.find((r: any) => r.id === 'aiNetwork')
+                        const clusterName = get(networkForm, 'agentClusterInstall.spec.clusterDeploymentRef.name')
+                        const clusterNamespace = get(networkForm, 'agentClusterInstall.metadata.namespace')
+                        patchNetwork(networkForm.agentClusterInstall, networkForm.active).then((status) => {
+                            resolve(status)
+                            if (status !== 'ERROR') {
+                                setCreationStatus({
+                                    status,
+                                    messages: ['Configured cluster network. Redirecting to cluster details...'],
+                                })
+                                setTimeout(() => {
+                                    history.push(
+                                        NavigationPath.clusterCreateProgress
+                                            .replace(':namespace', clusterNamespace as string)
+                                            .replace(':name', clusterName as string)
+                                    )
+                                }, 2000)
+                            }
+                        })
+                    })
+                }
+
                 break
         }
     }
@@ -290,6 +368,52 @@ export default function CreateClusterPage() {
         }
     }
 
+    const patchNetwork = async (
+        agentClusterInstall: CIM.AgentClusterInstallK8sResource,
+        values: CIM.NetworkConfigurationValues
+    ) => {
+        const patches = getNetworkingPatches(agentClusterInstall, values)
+        const patch = async () => {
+            let status = 'DONE'
+            let messages = ['Configured the cluster network']
+            try {
+                if (patches.length > 0) {
+                    await patchResource(agentClusterInstall, patches).promise
+                }
+            } catch (e) {
+                status = 'ERROR'
+                const msg = e instanceof Error ? e.message : ''
+                messages = [`Failed to configure the cluster network: ${msg}`]
+            }
+            setCreationStatus({ status, messages })
+            return status
+        }
+        setCreationStatus({ status: 'IN_PROGRESS', messages: ['Configuring the cluster network'] })
+        return patch()
+    }
+
+    const onControlSelect = (control: any) => {
+        if (control.controlId === 'infrastructure') {
+            if (control.active?.includes('AI') && !isInfraEnvAvailable) {
+                setWarning({
+                    title: t('cim:cim.infra.missing.warning.title'),
+                    text: t('cim:cim.infra.missing.warning.text'),
+                    linkText: t('cim:cim.infra.manage.link'),
+                    linkTo: NavigationPath.infraEnvironments,
+                })
+            } else {
+                setWarning(undefined)
+            }
+        }
+    }
+
+    const controlData = getControlData(
+        <Warning />,
+        onControlSelect,
+        settings.awsPrivateWizardStep === 'enabled',
+        settings.singleNodeOpenshift === 'enabled'
+    )
+
     return (
         <AcmPage
             header={
@@ -320,27 +444,34 @@ export default function CreateClusterPage() {
             <AcmErrorBoundary>
                 <AcmPageContent id="create-cluster">
                     <PageSection className="pf-c-content" variant="light" isFilled type="wizard">
-                        <TemplateEditor
-                            wizardClassName={classes.wizardBody}
-                            type={'cluster'}
-                            title={'Cluster YAML'}
-                            monacoEditor={<MonacoEditor />}
-                            controlData={controlData}
-                            template={template}
-                            portals={Portals}
-                            fetchControl={fetchControl}
-                            createControl={{
-                                createResource,
-                                cancelCreate,
-                                pauseCreate,
-                                creationStatus: creationStatus?.status,
-                                creationMsg: creationStatus?.messages,
-                            }}
-                            logging={process.env.NODE_ENV !== 'production'}
-                            i18n={i18n}
-                            onControlInitialize={onControlInitialize}
-                            onControlChange={onControlChange}
-                        />
+                        <WarningContext.Provider value={warning}>
+                            <TemplateEditor
+                                wizardClassName={classes.wizardBody}
+                                type={'cluster'}
+                                title={'Cluster YAML'}
+                                monacoEditor={<MonacoEditor />}
+                                controlData={controlData}
+                                template={template}
+                                portals={Portals}
+                                fetchControl={fetchControl}
+                                createControl={{
+                                    createResource,
+                                    cancelCreate,
+                                    pauseCreate,
+                                    creationStatus: creationStatus?.status,
+                                    creationMsg: creationStatus?.messages,
+                                    resetStatus: () => {
+                                        setCreationStatus(undefined)
+                                    },
+                                }}
+                                logging={process.env.NODE_ENV !== 'production'}
+                                i18n={i18n}
+                                onControlInitialize={onControlInitialize}
+                                onControlChange={onControlChange}
+                                ref={templateEditorRef}
+                                controlProps={selectedConnection}
+                            />
+                        </WarningContext.Provider>
                     </PageSection>
                 </AcmPageContent>
             </AcmErrorBoundary>
