@@ -1,9 +1,14 @@
 /* Copyright Contributors to the Open Cluster Management project */
 
-import fs from 'fs'
-import path from 'path'
+// eslint-disable-next-line no-use-before-define
+import React from 'react'
+import { Trans } from 'react-i18next'
+
 import Handlebars from 'handlebars'
 import installConfigHbs from '../templates/install-config.hbs'
+import aiTemplateHbs from '../templates/assisted-installer/assisted-template.hbs'
+import { AcmIconVariant, AcmIcon } from '@open-cluster-management/ui-components'
+import { CIM } from 'openshift-assisted-ui-lib'
 
 import getControlDataAWS from './ControlDataAWS'
 import getControlDataGCP from './ControlDataGCP'
@@ -12,11 +17,14 @@ import getControlDataVMW from './ControlDataVMW'
 import getControlDataBMC from './ControlDataBMC'
 import getControlDataOST from './ControlDataOST'
 import { RedHatLogo, AwsLogo, GoogleLogo, AzureLogo, VMwareLogo, BaremetalLogo } from './Logos'
+import controlDataAI from './ControlDataAI'
+import Deprecated from '../../components/Deprecated'
 
-const installConfig =
-    typeof installConfigHbs !== 'string'
-        ? installConfigHbs
-        : Handlebars.compile(fs.readFileSync(path.resolve(__dirname, '../templates/install-config.hbs'), 'utf8'))
+const { TechnologyPreview, PreviewBadgePosition } = CIM
+
+const installConfig = Handlebars.compile(installConfigHbs)
+
+const aiTemplate = Handlebars.compile(aiTemplateHbs)
 
 export const getActiveCardID = (control, fetchData = {}) => {
     const { requestedUIDs } = fetchData
@@ -26,17 +34,7 @@ export const getActiveCardID = (control, fetchData = {}) => {
     return null
 }
 
-export const getDistributionTitle = (ctrlData, groupData, i18n) => {
-    const activeObject = groupData.find((object) => object.id === 'distribution')
-    const active = activeObject['active']
-    if (active && activeObject['availableMap']) {
-        const title = activeObject['availableMap'][active].title
-        return i18n('creation.ocp.choose.infrastructure', [title])
-    }
-    return ''
-}
-
-export const controlData = [
+export const getControlData = (warning, onControlSelect, awsPrivateFeatureGate = false, snoFeatureGate = false) => [
     ///////////////////////  container platform  /////////////////////////////////////
     {
         id: 'distStep',
@@ -49,111 +47,109 @@ export const controlData = [
         active: false,
     },
     {
-        id: 'chooseDist',
-        type: 'title',
-        info: 'creation.ocp.choose.distribution',
-        tooltip: 'tooltip.creation.ocp.choose.distribution',
-    },
-    {
-        id: 'distribution',
-        type: 'cards',
-        sort: false,
-        pauseControlCreationHereUntilSelected: false,
-        active: 'OpenShift',
-        available: [
-            {
-                id: 'OpenShift',
-                logo: <RedHatLogo />,
-                title: 'cluster.create.ocp.subtitle',
-            },
-        ],
-        validation: {
-            notification: 'creation.ocp.cluster.must.select.orchestration',
-            required: true,
-        },
+        id: 'warning',
+        type: 'custom',
+        component: warning,
     },
     ///////////////////////  cloud  /////////////////////////////////////
-    {
-        id: 'chooseInfra',
-        type: 'title',
-        info: getDistributionTitle,
-        tooltip: 'tooltip.creation.ocp.choose.aws.infrastructure',
-        learnMore: 'https://docs.openshift.com/container-platform/4.3/installing/',
-    },
     {
         id: 'infrastructure',
         type: 'cards',
         sort: false,
         pauseControlCreationHereUntilSelected: true,
         scrollViewAfterSelection: 300,
+        onSelect: onControlSelect,
         available: [
             {
                 id: 'AWS',
                 logo: <AwsLogo />,
                 title: 'cluster.create.aws.subtitle',
                 change: {
-                    insertControlData: getControlDataAWS(),
+                    insertControlData: getControlDataAWS(true, awsPrivateFeatureGate, snoFeatureGate),
                     replacements: {
                         'install-config': { template: installConfig, encode: true, newTab: true },
                     },
                 },
+                section: 'Providers',
             },
             {
                 id: 'GCP',
                 logo: <GoogleLogo />,
                 title: 'cluster.create.google.subtitle',
                 change: {
-                    insertControlData: getControlDataGCP(),
+                    insertControlData: getControlDataGCP(true, snoFeatureGate),
                     replacements: {
                         'install-config': { template: installConfig, encode: true, newTab: true },
                     },
                 },
+                section: 'Providers',
             },
             {
                 id: 'Azure',
                 logo: <AzureLogo />,
                 title: 'cluster.create.azure.subtitle',
                 change: {
-                    insertControlData: getControlDataAZR(),
+                    insertControlData: getControlDataAZR(true, snoFeatureGate),
                     replacements: {
                         'install-config': { template: installConfig, encode: true, newTab: true },
                     },
                 },
+                section: 'Providers',
             },
             {
                 id: 'vSphere',
                 logo: <VMwareLogo />,
                 title: 'cluster.create.vmware.subtitle',
                 change: {
-                    insertControlData: getControlDataVMW(),
+                    insertControlData: getControlDataVMW(true, snoFeatureGate),
                     replacements: {
                         'install-config': { template: installConfig, encode: true, newTab: true },
                     },
                 },
+                section: 'Providers',
             },
             {
                 id: 'OpenStack',
                 logo: <RedHatLogo />,
                 title: 'cluster.create.redhat.subtitle',
                 change: {
-                    insertControlData: getControlDataOST(),
+                    insertControlData: getControlDataOST(true, snoFeatureGate),
                     replacements: {
                         'install-config': { template: installConfig, encode: true, newTab: true },
                     },
                 },
+                section: 'Providers',
+            },
+            {
+                id: 'AI',
+                logo: <AcmIcon icon={AcmIconVariant.hybrid} />,
+                title: 'cluster.create.ai.subtitle',
+                tooltip: 'cluster.create.ai.tooltip',
+                text: <TechnologyPreview position={PreviewBadgePosition.inline} className="pf-u-font-size-xs" />,
+                change: {
+                    insertControlData: controlDataAI,
+                    replacements: {},
+                    replaceTemplate: aiTemplate,
+                },
+                section: 'Centrally managed',
             },
             {
                 id: 'BMC',
                 logo: <BaremetalLogo />,
                 title: 'cluster.create.baremetal.subtitle',
+                // text: <Deprecated />,
                 change: {
                     insertControlData: getControlDataBMC(),
                     replacements: {
                         'install-config': { template: installConfig, encode: true, newTab: true },
                     },
                 },
+                section: 'Providers',
             },
         ],
+        sectionTooltips: {
+            'Centrally managed': <Trans i18nKey="create:cluster.create.centrallymanaged.section.tooltip" />,
+        },
         active: getActiveCardID,
         validation: {
             notification: 'creation.ocp.cluster.must.select.infrastructure',
