@@ -1,12 +1,12 @@
 /* Copyright Contributors to the Open Cluster Management project */
-import { AcmButton, AcmDropdown } from '@stolostron/ui-components'
+import { AcmButton, AcmDropdown } from '@open-cluster-management/ui-components'
 import { ActionList, ActionListItem, Bullseye } from '@patternfly/react-core'
 import { useEffect, useState } from 'react'
 import { useTranslation } from 'react-i18next'
 import { Link, useHistory } from 'react-router-dom'
 import { canUser } from '../../../../../lib/rbac-util'
 import { NavigationPath } from '../../../../../NavigationPath'
-import { ManagedClusterDefinition } from '../../../../../resources/managed-cluster'
+import { ManagedClusterDefinition } from '../../../../../resources'
 
 export function AddCluster(props: { type: 'button' | 'dropdown'; buttonType?: 'primary' | 'link' }) {
     const { t } = useTranslation('cluster')
