@@ -1,7 +1,7 @@
 /* Copyright Contributors to the Open Cluster Management project */
-import { AcmAlert } from '@stolostron/ui-components'
+import { AcmAlert } from '@open-cluster-management/ui-components'
 import { useTranslation } from 'react-i18next'
-import { Cluster, clusterDangerStatuses } from '../../../../../lib/get-cluster'
+import { Cluster, clusterDangerStatuses } from '../../../../../resources'
 
 export function ClusterStatusMessageAlert(props: {
     cluster: Cluster
