@@ -1,13 +1,12 @@
 /* Copyright Contributors to the Open Cluster Management project */
-import { AcmProgressTracker, ProgressTrackerStep, StatusType } from '@stolostron/ui-components'
+import { ClusterStatus, getLatestAnsibleJob } from '../../../../../resources'
+import { AcmProgressTracker, ProgressTrackerStep, StatusType } from '@open-cluster-management/ui-components'
 import { Card, CardBody } from '@patternfly/react-core'
 import { useContext } from 'react'
 import { useTranslation } from 'react-i18next'
 import { useRecoilState } from 'recoil'
 import { ansibleJobState, clusterCuratorsState, configMapsState } from '../../../../../atoms'
 import { DOC_LINKS } from '../../../../../lib/doc-util'
-import { ClusterStatus } from '../../../../../lib/get-cluster'
-import { getLatestAnsibleJob } from '../../../../../resources/ansible-job'
 import { ClusterContext } from '../ClusterDetails/ClusterDetails'
 import { launchLogs } from './HiveNotification'
 
